==> webkit2gtk_2.34.1.orig.tar.xz: webkitgtk-2.34.1/Source/WebCore/testing/FakeXRInputSourceInit.h <==
/*
 * Copyright (C) 2020 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBXR)

#include "FakeXRButtonStateInit.h"
#include "FakeXRRigidTransformInit.h"
#include "XREye.h"
#include "XRHandedness.h"
#include "XRTargetRayMode.h"
#include <wtf/Vector.h>

namespace WebCore {

struct FakeXRInputSourceInit {
    XRHandedness handedness;
    XRTargetRayMode targetRayMode;
    FakeXRRigidTransformInit pointerOrigin;
    Vector<String> profiles;
    bool selectionStarted { false };
    bool selectionClicked { false };
    Vector<FakeXRButtonStateInit> supportedButtons;
    FakeXRRigidTransformInit gripOrigin;
};

} // namespace WebCore

#endif // ENABLE(WEBXR)

==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/testing/FakeXRInputSourceInit.h <==
/*
 * Copyright (C) 2020 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBXR)

#include "FakeXRButtonStateInit.h"
#include "FakeXRRigidTransformInit.h"
#include "XREye.h"
#include "XRHandedness.h"
#include "XRTargetRayMode.h"
#include <wtf/Vector.h>

#if ENABLE(WEBXR_HANDS)
#include "FakeXRJointStateInit.h"
#endif

namespace WebCore {

struct FakeXRInputSourceInit {
    XRHandedness handedness;
    XRTargetRayMode targetRayMode;
    FakeXRRigidTransformInit pointerOrigin;
    Vector<String> profiles;
    bool selectionStarted { false };
    bool selectionClicked { false };
    Vector<FakeXRButtonStateInit> supportedButtons;
    FakeXRRigidTransformInit gripOrigin;
#if ENABLE(WEBXR_HANDS)
    Vector<FakeXRJointStateInit> handJoints;
#endif
};

} // namespace WebCore

#endif // ENABLE(WEBXR)
